#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosChooseDishGroupModel import PosChooseDishGroupModel
from alipay.aop.api.domain.PosSkuModel import PosSkuModel
from alipay.aop.api.domain.PosFixedDishGroupModel import PosFixedDishGroupModel
from alipay.aop.api.domain.PosDishMaterialModel import PosDishMaterialModel
from alipay.aop.api.domain.PosDishPracticeModel import PosDishPracticeModel
from alipay.aop.api.domain.PosStallModel import PosStallModel


class PosDishModel(object):

    def __init__(self):
        self._category_big_id = None
        self._choose_dish_group_list = None
        self._cook_id = None
        self._create_user = None
        self._dish_id = None
        self._dish_img = None
        self._dish_name = None
        self._dish_sku_list = None
        self._en_remember_code = None
        self._fixed_dish_group_list = None
        self._making_time = None
        self._material_list = None
        self._max_copies_per_time = None
        self._min_serving = None
        self._nb_remember_code = None
        self._practice_list = None
        self._remarks = None
        self._sell_price = None
        self._shop_id = None
        self._stall_list = None
        self._status = None
        self._sync_type = None
        self._tags = None
        self._type_big = None
        self._type_small = None
        self._unit_name = None
        self._update_user = None

    @property
    def category_big_id(self):
        return self._category_big_id

    @category_big_id.setter
    def category_big_id(self, value):
        self._category_big_id = value
    @property
    def choose_dish_group_list(self):
        return self._choose_dish_group_list

    @choose_dish_group_list.setter
    def choose_dish_group_list(self, value):
        if isinstance(value, list):
            self._choose_dish_group_list = list()
            for i in value:
                if isinstance(i, PosChooseDishGroupModel):
                    self._choose_dish_group_list.append(i)
                else:
                    self._choose_dish_group_list.append(PosChooseDishGroupModel.from_alipay_dict(i))
    @property
    def cook_id(self):
        return self._cook_id

    @cook_id.setter
    def cook_id(self, value):
        self._cook_id = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_img(self):
        return self._dish_img

    @dish_img.setter
    def dish_img(self, value):
        self._dish_img = value
    @property
    def dish_name(self):
        return self._dish_name

    @dish_name.setter
    def dish_name(self, value):
        self._dish_name = value
    @property
    def dish_sku_list(self):
        return self._dish_sku_list

    @dish_sku_list.setter
    def dish_sku_list(self, value):
        if isinstance(value, list):
            self._dish_sku_list = list()
            for i in value:
                if isinstance(i, PosSkuModel):
                    self._dish_sku_list.append(i)
                else:
                    self._dish_sku_list.append(PosSkuModel.from_alipay_dict(i))
    @property
    def en_remember_code(self):
        return self._en_remember_code

    @en_remember_code.setter
    def en_remember_code(self, value):
        self._en_remember_code = value
    @property
    def fixed_dish_group_list(self):
        return self._fixed_dish_group_list

    @fixed_dish_group_list.setter
    def fixed_dish_group_list(self, value):
        if isinstance(value, list):
            self._fixed_dish_group_list = list()
            for i in value:
                if isinstance(i, PosFixedDishGroupModel):
                    self._fixed_dish_group_list.append(i)
                else:
                    self._fixed_dish_group_list.append(PosFixedDishGroupModel.from_alipay_dict(i))
    @property
    def making_time(self):
        return self._making_time

    @making_time.setter
    def making_time(self, value):
        self._making_time = value
    @property
    def material_list(self):
        return self._material_list

    @material_list.setter
    def material_list(self, value):
        if isinstance(value, list):
            self._material_list = list()
            for i in value:
                if isinstance(i, PosDishMaterialModel):
                    self._material_list.append(i)
                else:
                    self._material_list.append(PosDishMaterialModel.from_alipay_dict(i))
    @property
    def max_copies_per_time(self):
        return self._max_copies_per_time

    @max_copies_per_time.setter
    def max_copies_per_time(self, value):
        self._max_copies_per_time = value
    @property
    def min_serving(self):
        return self._min_serving

    @min_serving.setter
    def min_serving(self, value):
        self._min_serving = value
    @property
    def nb_remember_code(self):
        return self._nb_remember_code

    @nb_remember_code.setter
    def nb_remember_code(self, value):
        self._nb_remember_code = value
    @property
    def practice_list(self):
        return self._practice_list

    @practice_list.setter
    def practice_list(self, value):
        if isinstance(value, list):
            self._practice_list = list()
            for i in value:
                if isinstance(i, PosDishPracticeModel):
                    self._practice_list.append(i)
                else:
                    self._practice_list.append(PosDishPracticeModel.from_alipay_dict(i))
    @property
    def remarks(self):
        return self._remarks

    @remarks.setter
    def remarks(self, value):
        self._remarks = value
    @property
    def sell_price(self):
        return self._sell_price

    @sell_price.setter
    def sell_price(self, value):
        self._sell_price = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def stall_list(self):
        return self._stall_list

    @stall_list.setter
    def stall_list(self, value):
        if isinstance(value, list):
            self._stall_list = list()
            for i in value:
                if isinstance(i, PosStallModel):
                    self._stall_list.append(i)
                else:
                    self._stall_list.append(PosStallModel.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sync_type(self):
        return self._sync_type

    @sync_type.setter
    def sync_type(self, value):
        self._sync_type = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def type_big(self):
        return self._type_big

    @type_big.setter
    def type_big(self, value):
        self._type_big = value
    @property
    def type_small(self):
        return self._type_small

    @type_small.setter
    def type_small(self, value):
        self._type_small = value
    @property
    def unit_name(self):
        return self._unit_name

    @unit_name.setter
    def unit_name(self, value):
        self._unit_name = value
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_big_id:
            if hasattr(self.category_big_id, 'to_alipay_dict'):
                params['category_big_id'] = self.category_big_id.to_alipay_dict()
            else:
                params['category_big_id'] = self.category_big_id
        if self.choose_dish_group_list:
            if isinstance(self.choose_dish_group_list, list):
                for i in range(0, len(self.choose_dish_group_list)):
                    element = self.choose_dish_group_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.choose_dish_group_list[i] = element.to_alipay_dict()
            if hasattr(self.choose_dish_group_list, 'to_alipay_dict'):
                params['choose_dish_group_list'] = self.choose_dish_group_list.to_alipay_dict()
            else:
                params['choose_dish_group_list'] = self.choose_dish_group_list
        if self.cook_id:
            if hasattr(self.cook_id, 'to_alipay_dict'):
                params['cook_id'] = self.cook_id.to_alipay_dict()
            else:
                params['cook_id'] = self.cook_id
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_img:
            if hasattr(self.dish_img, 'to_alipay_dict'):
                params['dish_img'] = self.dish_img.to_alipay_dict()
            else:
                params['dish_img'] = self.dish_img
        if self.dish_name:
            if hasattr(self.dish_name, 'to_alipay_dict'):
                params['dish_name'] = self.dish_name.to_alipay_dict()
            else:
                params['dish_name'] = self.dish_name
        if self.dish_sku_list:
            if isinstance(self.dish_sku_list, list):
                for i in range(0, len(self.dish_sku_list)):
                    element = self.dish_sku_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_sku_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_sku_list, 'to_alipay_dict'):
                params['dish_sku_list'] = self.dish_sku_list.to_alipay_dict()
            else:
                params['dish_sku_list'] = self.dish_sku_list
        if self.en_remember_code:
            if hasattr(self.en_remember_code, 'to_alipay_dict'):
                params['en_remember_code'] = self.en_remember_code.to_alipay_dict()
            else:
                params['en_remember_code'] = self.en_remember_code
        if self.fixed_dish_group_list:
            if isinstance(self.fixed_dish_group_list, list):
                for i in range(0, len(self.fixed_dish_group_list)):
                    element = self.fixed_dish_group_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.fixed_dish_group_list[i] = element.to_alipay_dict()
            if hasattr(self.fixed_dish_group_list, 'to_alipay_dict'):
                params['fixed_dish_group_list'] = self.fixed_dish_group_list.to_alipay_dict()
            else:
                params['fixed_dish_group_list'] = self.fixed_dish_group_list
        if self.making_time:
            if hasattr(self.making_time, 'to_alipay_dict'):
                params['making_time'] = self.making_time.to_alipay_dict()
            else:
                params['making_time'] = self.making_time
        if self.material_list:
            if isinstance(self.material_list, list):
                for i in range(0, len(self.material_list)):
                    element = self.material_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.material_list[i] = element.to_alipay_dict()
            if hasattr(self.material_list, 'to_alipay_dict'):
                params['material_list'] = self.material_list.to_alipay_dict()
            else:
                params['material_list'] = self.material_list
        if self.max_copies_per_time:
            if hasattr(self.max_copies_per_time, 'to_alipay_dict'):
                params['max_copies_per_time'] = self.max_copies_per_time.to_alipay_dict()
            else:
                params['max_copies_per_time'] = self.max_copies_per_time
        if self.min_serving:
            if hasattr(self.min_serving, 'to_alipay_dict'):
                params['min_serving'] = self.min_serving.to_alipay_dict()
            else:
                params['min_serving'] = self.min_serving
        if self.nb_remember_code:
            if hasattr(self.nb_remember_code, 'to_alipay_dict'):
                params['nb_remember_code'] = self.nb_remember_code.to_alipay_dict()
            else:
                params['nb_remember_code'] = self.nb_remember_code
        if self.practice_list:
            if isinstance(self.practice_list, list):
                for i in range(0, len(self.practice_list)):
                    element = self.practice_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.practice_list[i] = element.to_alipay_dict()
            if hasattr(self.practice_list, 'to_alipay_dict'):
                params['practice_list'] = self.practice_list.to_alipay_dict()
            else:
                params['practice_list'] = self.practice_list
        if self.remarks:
            if hasattr(self.remarks, 'to_alipay_dict'):
                params['remarks'] = self.remarks.to_alipay_dict()
            else:
                params['remarks'] = self.remarks
        if self.sell_price:
            if hasattr(self.sell_price, 'to_alipay_dict'):
                params['sell_price'] = self.sell_price.to_alipay_dict()
            else:
                params['sell_price'] = self.sell_price
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.stall_list:
            if isinstance(self.stall_list, list):
                for i in range(0, len(self.stall_list)):
                    element = self.stall_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.stall_list[i] = element.to_alipay_dict()
            if hasattr(self.stall_list, 'to_alipay_dict'):
                params['stall_list'] = self.stall_list.to_alipay_dict()
            else:
                params['stall_list'] = self.stall_list
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sync_type:
            if hasattr(self.sync_type, 'to_alipay_dict'):
                params['sync_type'] = self.sync_type.to_alipay_dict()
            else:
                params['sync_type'] = self.sync_type
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.type_big:
            if hasattr(self.type_big, 'to_alipay_dict'):
                params['type_big'] = self.type_big.to_alipay_dict()
            else:
                params['type_big'] = self.type_big
        if self.type_small:
            if hasattr(self.type_small, 'to_alipay_dict'):
                params['type_small'] = self.type_small.to_alipay_dict()
            else:
                params['type_small'] = self.type_small
        if self.unit_name:
            if hasattr(self.unit_name, 'to_alipay_dict'):
                params['unit_name'] = self.unit_name.to_alipay_dict()
            else:
                params['unit_name'] = self.unit_name
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosDishModel()
        if 'category_big_id' in d:
            o.category_big_id = d['category_big_id']
        if 'choose_dish_group_list' in d:
            o.choose_dish_group_list = d['choose_dish_group_list']
        if 'cook_id' in d:
            o.cook_id = d['cook_id']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_img' in d:
            o.dish_img = d['dish_img']
        if 'dish_name' in d:
            o.dish_name = d['dish_name']
        if 'dish_sku_list' in d:
            o.dish_sku_list = d['dish_sku_list']
        if 'en_remember_code' in d:
            o.en_remember_code = d['en_remember_code']
        if 'fixed_dish_group_list' in d:
            o.fixed_dish_group_list = d['fixed_dish_group_list']
        if 'making_time' in d:
            o.making_time = d['making_time']
        if 'material_list' in d:
            o.material_list = d['material_list']
        if 'max_copies_per_time' in d:
            o.max_copies_per_time = d['max_copies_per_time']
        if 'min_serving' in d:
            o.min_serving = d['min_serving']
        if 'nb_remember_code' in d:
            o.nb_remember_code = d['nb_remember_code']
        if 'practice_list' in d:
            o.practice_list = d['practice_list']
        if 'remarks' in d:
            o.remarks = d['remarks']
        if 'sell_price' in d:
            o.sell_price = d['sell_price']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'stall_list' in d:
            o.stall_list = d['stall_list']
        if 'status' in d:
            o.status = d['status']
        if 'sync_type' in d:
            o.sync_type = d['sync_type']
        if 'tags' in d:
            o.tags = d['tags']
        if 'type_big' in d:
            o.type_big = d['type_big']
        if 'type_small' in d:
            o.type_small = d['type_small']
        if 'unit_name' in d:
            o.unit_name = d['unit_name']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RepayTradeDetail(object):

    def __init__(self):
        self._repay_amount = None
        self._trade_no = None

    @property
    def repay_amount(self):
        return self._repay_amount

    @repay_amount.setter
    def repay_amount(self, value):
        self._repay_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.repay_amount:
            if hasattr(self.repay_amount, 'to_alipay_dict'):
                params['repay_amount'] = self.repay_amount.to_alipay_dict()
            else:
                params['repay_amount'] = self.repay_amount
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RepayTradeDetail()
        if 'repay_amount' in d:
            o.repay_amount = d['repay_amount']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderVoucherAvailableShopModify(object):

    def __init__(self):
        self._real_shop_ids = None
        self._shop_ids = None

    @property
    def real_shop_ids(self):
        return self._real_shop_ids

    @real_shop_ids.setter
    def real_shop_ids(self, value):
        if isinstance(value, list):
            self._real_shop_ids = list()
            for i in value:
                self._real_shop_ids.append(i)
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.real_shop_ids:
            if isinstance(self.real_shop_ids, list):
                for i in range(0, len(self.real_shop_ids)):
                    element = self.real_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.real_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.real_shop_ids, 'to_alipay_dict'):
                params['real_shop_ids'] = self.real_shop_ids.to_alipay_dict()
            else:
                params['real_shop_ids'] = self.real_shop_ids
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderVoucherAvailableShopModify()
        if 'real_shop_ids' in d:
            o.real_shop_ids = d['real_shop_ids']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ReceiverIstd(object):

    def __init__(self):
        self._address = None
        self._address_detail = None
        self._city = None
        self._coordinate_type = None
        self._lat = None
        self._lng = None
        self._mobile_no = None
        self._name = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def address_detail(self):
        return self._address_detail

    @address_detail.setter
    def address_detail(self, value):
        self._address_detail = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def coordinate_type(self):
        return self._coordinate_type

    @coordinate_type.setter
    def coordinate_type(self, value):
        self._coordinate_type = value
    @property
    def lat(self):
        return self._lat

    @lat.setter
    def lat(self, value):
        self._lat = value
    @property
    def lng(self):
        return self._lng

    @lng.setter
    def lng(self, value):
        self._lng = value
    @property
    def mobile_no(self):
        return self._mobile_no

    @mobile_no.setter
    def mobile_no(self, value):
        self._mobile_no = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.address_detail:
            if hasattr(self.address_detail, 'to_alipay_dict'):
                params['address_detail'] = self.address_detail.to_alipay_dict()
            else:
                params['address_detail'] = self.address_detail
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.coordinate_type:
            if hasattr(self.coordinate_type, 'to_alipay_dict'):
                params['coordinate_type'] = self.coordinate_type.to_alipay_dict()
            else:
                params['coordinate_type'] = self.coordinate_type
        if self.lat:
            if hasattr(self.lat, 'to_alipay_dict'):
                params['lat'] = self.lat.to_alipay_dict()
            else:
                params['lat'] = self.lat
        if self.lng:
            if hasattr(self.lng, 'to_alipay_dict'):
                params['lng'] = self.lng.to_alipay_dict()
            else:
                params['lng'] = self.lng
        if self.mobile_no:
            if hasattr(self.mobile_no, 'to_alipay_dict'):
                params['mobile_no'] = self.mobile_no.to_alipay_dict()
            else:
                params['mobile_no'] = self.mobile_no
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReceiverIstd()
        if 'address' in d:
            o.address = d['address']
        if 'address_detail' in d:
            o.address_detail = d['address_detail']
        if 'city' in d:
            o.city = d['city']
        if 'coordinate_type' in d:
            o.coordinate_type = d['coordinate_type']
        if 'lat' in d:
            o.lat = d['lat']
        if 'lng' in d:
            o.lng = d['lng']
        if 'mobile_no' in d:
            o.mobile_no = d['mobile_no']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BatchInfo import BatchInfo


class AlipayBossContractManagementIdentifyModel(object):

    def __init__(self):
        self._biz_source = None
        self._contracts = None

    @property
    def biz_source(self):
        return self._biz_source

    @biz_source.setter
    def biz_source(self, value):
        self._biz_source = value
    @property
    def contracts(self):
        return self._contracts

    @contracts.setter
    def contracts(self, value):
        if isinstance(value, list):
            self._contracts = list()
            for i in value:
                if isinstance(i, BatchInfo):
                    self._contracts.append(i)
                else:
                    self._contracts.append(BatchInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.biz_source:
            if hasattr(self.biz_source, 'to_alipay_dict'):
                params['biz_source'] = self.biz_source.to_alipay_dict()
            else:
                params['biz_source'] = self.biz_source
        if self.contracts:
            if isinstance(self.contracts, list):
                for i in range(0, len(self.contracts)):
                    element = self.contracts[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contracts[i] = element.to_alipay_dict()
            if hasattr(self.contracts, 'to_alipay_dict'):
                params['contracts'] = self.contracts.to_alipay_dict()
            else:
                params['contracts'] = self.contracts
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossContractManagementIdentifyModel()
        if 'biz_source' in d:
            o.biz_source = d['biz_source']
        if 'contracts' in d:
            o.contracts = d['contracts']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandProductionOrderSyncModel(object):

    def __init__(self):
        self._amount = None
        self._batch_no = None
        self._item_id = None
        self._project_no = None
        self._regional_warehouse = None
        self._value = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def project_no(self):
        return self._project_no

    @project_no.setter
    def project_no(self, value):
        self._project_no = value
    @property
    def regional_warehouse(self):
        return self._regional_warehouse

    @regional_warehouse.setter
    def regional_warehouse(self, value):
        self._regional_warehouse = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.project_no:
            if hasattr(self.project_no, 'to_alipay_dict'):
                params['project_no'] = self.project_no.to_alipay_dict()
            else:
                params['project_no'] = self.project_no
        if self.regional_warehouse:
            if hasattr(self.regional_warehouse, 'to_alipay_dict'):
                params['regional_warehouse'] = self.regional_warehouse.to_alipay_dict()
            else:
                params['regional_warehouse'] = self.regional_warehouse
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandProductionOrderSyncModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'project_no' in d:
            o.project_no = d['project_no']
        if 'regional_warehouse' in d:
            o.regional_warehouse = d['regional_warehouse']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InvoiceBillResponsePageDTO import InvoiceBillResponsePageDTO


class AlipayBossFncGfsettleprodInvoicebillQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossFncGfsettleprodInvoicebillQueryResponse, self).__init__()
        self._result_set = None

    @property
    def result_set(self):
        return self._result_set

    @result_set.setter
    def result_set(self, value):
        if isinstance(value, list):
            self._result_set = list()
            for i in value:
                if isinstance(i, InvoiceBillResponsePageDTO):
                    self._result_set.append(i)
                else:
                    self._result_set.append(InvoiceBillResponsePageDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayBossFncGfsettleprodInvoicebillQueryResponse, self).parse_response_content(response_content)
        if 'result_set' in response:
            self.result_set = response['result_set']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserGroupshoppingBenefitQueryModel(object):

    def __init__(self):
        self._group_id = None
        self._is_platform_invest = None
        self._item_id = None
        self._original_prize = None
        self._pin_prize = None
        self._pin_status = None
        self._scene = None
        self._user_id = None
        self._user_id_list = None

    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def is_platform_invest(self):
        return self._is_platform_invest

    @is_platform_invest.setter
    def is_platform_invest(self, value):
        self._is_platform_invest = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def original_prize(self):
        return self._original_prize

    @original_prize.setter
    def original_prize(self, value):
        self._original_prize = value
    @property
    def pin_prize(self):
        return self._pin_prize

    @pin_prize.setter
    def pin_prize(self, value):
        self._pin_prize = value
    @property
    def pin_status(self):
        return self._pin_status

    @pin_status.setter
    def pin_status(self, value):
        self._pin_status = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_id_list(self):
        return self._user_id_list

    @user_id_list.setter
    def user_id_list(self, value):
        if isinstance(value, list):
            self._user_id_list = list()
            for i in value:
                self._user_id_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.is_platform_invest:
            if hasattr(self.is_platform_invest, 'to_alipay_dict'):
                params['is_platform_invest'] = self.is_platform_invest.to_alipay_dict()
            else:
                params['is_platform_invest'] = self.is_platform_invest
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.original_prize:
            if hasattr(self.original_prize, 'to_alipay_dict'):
                params['original_prize'] = self.original_prize.to_alipay_dict()
            else:
                params['original_prize'] = self.original_prize
        if self.pin_prize:
            if hasattr(self.pin_prize, 'to_alipay_dict'):
                params['pin_prize'] = self.pin_prize.to_alipay_dict()
            else:
                params['pin_prize'] = self.pin_prize
        if self.pin_status:
            if hasattr(self.pin_status, 'to_alipay_dict'):
                params['pin_status'] = self.pin_status.to_alipay_dict()
            else:
                params['pin_status'] = self.pin_status
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_id_list:
            if isinstance(self.user_id_list, list):
                for i in range(0, len(self.user_id_list)):
                    element = self.user_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_id_list[i] = element.to_alipay_dict()
            if hasattr(self.user_id_list, 'to_alipay_dict'):
                params['user_id_list'] = self.user_id_list.to_alipay_dict()
            else:
                params['user_id_list'] = self.user_id_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserGroupshoppingBenefitQueryModel()
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'is_platform_invest' in d:
            o.is_platform_invest = d['is_platform_invest']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'original_prize' in d:
            o.original_prize = d['original_prize']
        if 'pin_prize' in d:
            o.pin_prize = d['pin_prize']
        if 'pin_status' in d:
            o.pin_status = d['pin_status']
        if 'scene' in d:
            o.scene = d['scene']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_id_list' in d:
            o.user_id_list = d['user_id_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsDataDsbEstimateQueryModel(object):

    def __init__(self):
        self._estimate_no = None
        self._frame_no = None
        self._garage_type = None
        self._license_no = None

    @property
    def estimate_no(self):
        return self._estimate_no

    @estimate_no.setter
    def estimate_no(self, value):
        self._estimate_no = value
    @property
    def frame_no(self):
        return self._frame_no

    @frame_no.setter
    def frame_no(self, value):
        self._frame_no = value
    @property
    def garage_type(self):
        return self._garage_type

    @garage_type.setter
    def garage_type(self, value):
        self._garage_type = value
    @property
    def license_no(self):
        return self._license_no

    @license_no.setter
    def license_no(self, value):
        self._license_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.estimate_no:
            if hasattr(self.estimate_no, 'to_alipay_dict'):
                params['estimate_no'] = self.estimate_no.to_alipay_dict()
            else:
                params['estimate_no'] = self.estimate_no
        if self.frame_no:
            if hasattr(self.frame_no, 'to_alipay_dict'):
                params['frame_no'] = self.frame_no.to_alipay_dict()
            else:
                params['frame_no'] = self.frame_no
        if self.garage_type:
            if hasattr(self.garage_type, 'to_alipay_dict'):
                params['garage_type'] = self.garage_type.to_alipay_dict()
            else:
                params['garage_type'] = self.garage_type
        if self.license_no:
            if hasattr(self.license_no, 'to_alipay_dict'):
                params['license_no'] = self.license_no.to_alipay_dict()
            else:
                params['license_no'] = self.license_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsDataDsbEstimateQueryModel()
        if 'estimate_no' in d:
            o.estimate_no = d['estimate_no']
        if 'frame_no' in d:
            o.frame_no = d['frame_no']
        if 'garage_type' in d:
            o.garage_type = d['garage_type']
        if 'license_no' in d:
            o.license_no = d['license_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ArrangementVORes import ArrangementVORes


class AntProdpaasArrangementCommonQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntProdpaasArrangementCommonQueryResponse, self).__init__()
        self._arrangements = None

    @property
    def arrangements(self):
        return self._arrangements

    @arrangements.setter
    def arrangements(self, value):
        if isinstance(value, list):
            self._arrangements = list()
            for i in value:
                if isinstance(i, ArrangementVORes):
                    self._arrangements.append(i)
                else:
                    self._arrangements.append(ArrangementVORes.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntProdpaasArrangementCommonQueryResponse, self).parse_response_content(response_content)
        if 'arrangements' in response:
            self.arrangements = response['arrangements']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCertifyIdentifyFileQueryModel(object):

    def __init__(self):
        self._file_url = None

    @property
    def file_url(self):
        return self._file_url

    @file_url.setter
    def file_url(self, value):
        self._file_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.file_url:
            if hasattr(self.file_url, 'to_alipay_dict'):
                params['file_url'] = self.file_url.to_alipay_dict()
            else:
                params['file_url'] = self.file_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCertifyIdentifyFileQueryModel()
        if 'file_url' in d:
            o.file_url = d['file_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PaytoolResultDetail import PaytoolResultDetail


class AlipayBusinessOrderPayResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessOrderPayResponse, self).__init__()
        self._merchant_order_no = None
        self._order_no = None
        self._order_status = None
        self._paytool_list = None

    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def paytool_list(self):
        return self._paytool_list

    @paytool_list.setter
    def paytool_list(self, value):
        if isinstance(value, list):
            self._paytool_list = list()
            for i in value:
                if isinstance(i, PaytoolResultDetail):
                    self._paytool_list.append(i)
                else:
                    self._paytool_list.append(PaytoolResultDetail.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessOrderPayResponse, self).parse_response_content(response_content)
        if 'merchant_order_no' in response:
            self.merchant_order_no = response['merchant_order_no']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'paytool_list' in response:
            self.paytool_list = response['paytool_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InfoSource import InfoSource


class AlipayCommerceKidsAccountConsultModel(object):

    def __init__(self):
        self._child_cert_no = None
        self._child_cert_type = None
        self._info_source = None
        self._operator_uid = None
        self._parent_uid = None
        self._scene_code = None

    @property
    def child_cert_no(self):
        return self._child_cert_no

    @child_cert_no.setter
    def child_cert_no(self, value):
        self._child_cert_no = value
    @property
    def child_cert_type(self):
        return self._child_cert_type

    @child_cert_type.setter
    def child_cert_type(self, value):
        self._child_cert_type = value
    @property
    def info_source(self):
        return self._info_source

    @info_source.setter
    def info_source(self, value):
        if isinstance(value, InfoSource):
            self._info_source = value
        else:
            self._info_source = InfoSource.from_alipay_dict(value)
    @property
    def operator_uid(self):
        return self._operator_uid

    @operator_uid.setter
    def operator_uid(self, value):
        self._operator_uid = value
    @property
    def parent_uid(self):
        return self._parent_uid

    @parent_uid.setter
    def parent_uid(self, value):
        self._parent_uid = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.child_cert_no:
            if hasattr(self.child_cert_no, 'to_alipay_dict'):
                params['child_cert_no'] = self.child_cert_no.to_alipay_dict()
            else:
                params['child_cert_no'] = self.child_cert_no
        if self.child_cert_type:
            if hasattr(self.child_cert_type, 'to_alipay_dict'):
                params['child_cert_type'] = self.child_cert_type.to_alipay_dict()
            else:
                params['child_cert_type'] = self.child_cert_type
        if self.info_source:
            if hasattr(self.info_source, 'to_alipay_dict'):
                params['info_source'] = self.info_source.to_alipay_dict()
            else:
                params['info_source'] = self.info_source
        if self.operator_uid:
            if hasattr(self.operator_uid, 'to_alipay_dict'):
                params['operator_uid'] = self.operator_uid.to_alipay_dict()
            else:
                params['operator_uid'] = self.operator_uid
        if self.parent_uid:
            if hasattr(self.parent_uid, 'to_alipay_dict'):
                params['parent_uid'] = self.parent_uid.to_alipay_dict()
            else:
                params['parent_uid'] = self.parent_uid
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceKidsAccountConsultModel()
        if 'child_cert_no' in d:
            o.child_cert_no = d['child_cert_no']
        if 'child_cert_type' in d:
            o.child_cert_type = d['child_cert_type']
        if 'info_source' in d:
            o.info_source = d['info_source']
        if 'operator_uid' in d:
            o.operator_uid = d['operator_uid']
        if 'parent_uid' in d:
            o.parent_uid = d['parent_uid']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInstserviceTokenCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInstserviceTokenCreateResponse, self).__init__()
        self._sign_token = None

    @property
    def sign_token(self):
        return self._sign_token

    @sign_token.setter
    def sign_token(self, value):
        self._sign_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInstserviceTokenCreateResponse, self).parse_response_content(response_content)
        if 'sign_token' in response:
            self.sign_token = response['sign_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FengdieActivitySchemaModel import FengdieActivitySchemaModel


class FengdieSitesPageModel(object):

    def __init__(self):
        self._alias = None
        self._is_home_page = None
        self._origin_url = None
        self._schema = None
        self._snapshot = None
        self._url = None

    @property
    def alias(self):
        return self._alias

    @alias.setter
    def alias(self, value):
        self._alias = value
    @property
    def is_home_page(self):
        return self._is_home_page

    @is_home_page.setter
    def is_home_page(self, value):
        self._is_home_page = value
    @property
    def origin_url(self):
        return self._origin_url

    @origin_url.setter
    def origin_url(self, value):
        self._origin_url = value
    @property
    def schema(self):
        return self._schema

    @schema.setter
    def schema(self, value):
        if isinstance(value, list):
            self._schema = list()
            for i in value:
                if isinstance(i, FengdieActivitySchemaModel):
                    self._schema.append(i)
                else:
                    self._schema.append(FengdieActivitySchemaModel.from_alipay_dict(i))
    @property
    def snapshot(self):
        return self._snapshot

    @snapshot.setter
    def snapshot(self, value):
        self._snapshot = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.alias:
            if hasattr(self.alias, 'to_alipay_dict'):
                params['alias'] = self.alias.to_alipay_dict()
            else:
                params['alias'] = self.alias
        if self.is_home_page:
            if hasattr(self.is_home_page, 'to_alipay_dict'):
                params['is_home_page'] = self.is_home_page.to_alipay_dict()
            else:
                params['is_home_page'] = self.is_home_page
        if self.origin_url:
            if hasattr(self.origin_url, 'to_alipay_dict'):
                params['origin_url'] = self.origin_url.to_alipay_dict()
            else:
                params['origin_url'] = self.origin_url
        if self.schema:
            if isinstance(self.schema, list):
                for i in range(0, len(self.schema)):
                    element = self.schema[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.schema[i] = element.to_alipay_dict()
            if hasattr(self.schema, 'to_alipay_dict'):
                params['schema'] = self.schema.to_alipay_dict()
            else:
                params['schema'] = self.schema
        if self.snapshot:
            if hasattr(self.snapshot, 'to_alipay_dict'):
                params['snapshot'] = self.snapshot.to_alipay_dict()
            else:
                params['snapshot'] = self.snapshot
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FengdieSitesPageModel()
        if 'alias' in d:
            o.alias = d['alias']
        if 'is_home_page' in d:
            o.is_home_page = d['is_home_page']
        if 'origin_url' in d:
            o.origin_url = d['origin_url']
        if 'schema' in d:
            o.schema = d['schema']
        if 'snapshot' in d:
            o.snapshot = d['snapshot']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceHellobikeLogSyncModel(object):

    def __init__(self):
        self._action_type = None
        self._channel = None
        self._city_code = None
        self._pay_price_cent = None
        self._pay_tool = None
        self._trace_id = None
        self._user_id = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def pay_price_cent(self):
        return self._pay_price_cent

    @pay_price_cent.setter
    def pay_price_cent(self, value):
        self._pay_price_cent = value
    @property
    def pay_tool(self):
        return self._pay_tool

    @pay_tool.setter
    def pay_tool(self, value):
        self._pay_tool = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.pay_price_cent:
            if hasattr(self.pay_price_cent, 'to_alipay_dict'):
                params['pay_price_cent'] = self.pay_price_cent.to_alipay_dict()
            else:
                params['pay_price_cent'] = self.pay_price_cent
        if self.pay_tool:
            if hasattr(self.pay_tool, 'to_alipay_dict'):
                params['pay_tool'] = self.pay_tool.to_alipay_dict()
            else:
                params['pay_tool'] = self.pay_tool
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceHellobikeLogSyncModel()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'channel' in d:
            o.channel = d['channel']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'pay_price_cent' in d:
            o.pay_price_cent = d['pay_price_cent']
        if 'pay_tool' in d:
            o.pay_tool = d['pay_tool']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringPosDishstatusModifyModel(object):

    def __init__(self):
        self._dish_ids = None
        self._status = None

    @property
    def dish_ids(self):
        return self._dish_ids

    @dish_ids.setter
    def dish_ids(self, value):
        if isinstance(value, list):
            self._dish_ids = list()
            for i in value:
                self._dish_ids.append(i)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.dish_ids:
            if isinstance(self.dish_ids, list):
                for i in range(0, len(self.dish_ids)):
                    element = self.dish_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_ids[i] = element.to_alipay_dict()
            if hasattr(self.dish_ids, 'to_alipay_dict'):
                params['dish_ids'] = self.dish_ids.to_alipay_dict()
            else:
                params['dish_ids'] = self.dish_ids
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosDishstatusModifyModel()
        if 'dish_ids' in d:
            o.dish_ids = d['dish_ids']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTransferPaymentNotifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTransferPaymentNotifyResponse, self).__init__()
        self._pass_through_info = None

    @property
    def pass_through_info(self):
        return self._pass_through_info

    @pass_through_info.setter
    def pass_through_info(self, value):
        self._pass_through_info = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTransferPaymentNotifyResponse, self).parse_response_content(response_content)
        if 'pass_through_info' in response:
            self.pass_through_info = response['pass_through_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenBpaasAppPublishModel(object):

    def __init__(self):
        self._app_version = None
        self._bpaas_app_id = None
        self._change_log = None
        self._file_digest = None
        self._file_md_5 = None
        self._package_file_size = None
        self._scm_download_url = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def bpaas_app_id(self):
        return self._bpaas_app_id

    @bpaas_app_id.setter
    def bpaas_app_id(self, value):
        self._bpaas_app_id = value
    @property
    def change_log(self):
        return self._change_log

    @change_log.setter
    def change_log(self, value):
        self._change_log = value
    @property
    def file_digest(self):
        return self._file_digest

    @file_digest.setter
    def file_digest(self, value):
        self._file_digest = value
    @property
    def file_md_5(self):
        return self._file_md_5

    @file_md_5.setter
    def file_md_5(self, value):
        self._file_md_5 = value
    @property
    def package_file_size(self):
        return self._package_file_size

    @package_file_size.setter
    def package_file_size(self, value):
        self._package_file_size = value
    @property
    def scm_download_url(self):
        return self._scm_download_url

    @scm_download_url.setter
    def scm_download_url(self, value):
        self._scm_download_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.bpaas_app_id:
            if hasattr(self.bpaas_app_id, 'to_alipay_dict'):
                params['bpaas_app_id'] = self.bpaas_app_id.to_alipay_dict()
            else:
                params['bpaas_app_id'] = self.bpaas_app_id
        if self.change_log:
            if hasattr(self.change_log, 'to_alipay_dict'):
                params['change_log'] = self.change_log.to_alipay_dict()
            else:
                params['change_log'] = self.change_log
        if self.file_digest:
            if hasattr(self.file_digest, 'to_alipay_dict'):
                params['file_digest'] = self.file_digest.to_alipay_dict()
            else:
                params['file_digest'] = self.file_digest
        if self.file_md_5:
            if hasattr(self.file_md_5, 'to_alipay_dict'):
                params['file_md_5'] = self.file_md_5.to_alipay_dict()
            else:
                params['file_md_5'] = self.file_md_5
        if self.package_file_size:
            if hasattr(self.package_file_size, 'to_alipay_dict'):
                params['package_file_size'] = self.package_file_size.to_alipay_dict()
            else:
                params['package_file_size'] = self.package_file_size
        if self.scm_download_url:
            if hasattr(self.scm_download_url, 'to_alipay_dict'):
                params['scm_download_url'] = self.scm_download_url.to_alipay_dict()
            else:
                params['scm_download_url'] = self.scm_download_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenBpaasAppPublishModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'bpaas_app_id' in d:
            o.bpaas_app_id = d['bpaas_app_id']
        if 'change_log' in d:
            o.change_log = d['change_log']
        if 'file_digest' in d:
            o.file_digest = d['file_digest']
        if 'file_md_5' in d:
            o.file_md_5 = d['file_md_5']
        if 'package_file_size' in d:
            o.package_file_size = d['package_file_size']
        if 'scm_download_url' in d:
            o.scm_download_url = d['scm_download_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsDataAutoScoreQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsDataAutoScoreQueryResponse, self).__init__()
        self._bill_no = None
        self._exclusive_score = None
        self._ext_info = None
        self._score = None
        self._uuid = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def exclusive_score(self):
        return self._exclusive_score

    @exclusive_score.setter
    def exclusive_score(self, value):
        self._exclusive_score = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value
    @property
    def uuid(self):
        return self._uuid

    @uuid.setter
    def uuid(self, value):
        self._uuid = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsDataAutoScoreQueryResponse, self).parse_response_content(response_content)
        if 'bill_no' in response:
            self.bill_no = response['bill_no']
        if 'exclusive_score' in response:
            self.exclusive_score = response['exclusive_score']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'score' in response:
            self.score = response['score']
        if 'uuid' in response:
            self.uuid = response['uuid']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandItemSecurityQueryModel(object):

    def __init__(self):
        self._front_category_id = None
        self._scene = None
        self._status = None
        self._target_id = None
        self._target_type = None

    @property
    def front_category_id(self):
        return self._front_category_id

    @front_category_id.setter
    def front_category_id(self, value):
        self._front_category_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_type(self):
        return self._target_type

    @target_type.setter
    def target_type(self, value):
        self._target_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.front_category_id:
            if hasattr(self.front_category_id, 'to_alipay_dict'):
                params['front_category_id'] = self.front_category_id.to_alipay_dict()
            else:
                params['front_category_id'] = self.front_category_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_type:
            if hasattr(self.target_type, 'to_alipay_dict'):
                params['target_type'] = self.target_type.to_alipay_dict()
            else:
                params['target_type'] = self.target_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandItemSecurityQueryModel()
        if 'front_category_id' in d:
            o.front_category_id = d['front_category_id']
        if 'scene' in d:
            o.scene = d['scene']
        if 'status' in d:
            o.status = d['status']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_type' in d:
            o.target_type = d['target_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MemberPointsScene import MemberPointsScene


class KoubeiMarketingDataSceneMemberpointsGetModel(object):

    def __init__(self):
        self._biz_info = None
        self._ext_info = None
        self._out_request_no = None
        self._scene_type = None
        self._user_id = None

    @property
    def biz_info(self):
        return self._biz_info

    @biz_info.setter
    def biz_info(self, value):
        if isinstance(value, MemberPointsScene):
            self._biz_info = value
        else:
            self._biz_info = MemberPointsScene.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_info:
            if hasattr(self.biz_info, 'to_alipay_dict'):
                params['biz_info'] = self.biz_info.to_alipay_dict()
            else:
                params['biz_info'] = self.biz_info
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingDataSceneMemberpointsGetModel()
        if 'biz_info' in d:
            o.biz_info = d['biz_info']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityExchangeVoucher(object):

    def __init__(self):
        self._amount = None
        self._floor_amount = None
        self._overdue_refundable = None
        self._refundable = None
        self._sale_amount = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def floor_amount(self):
        return self._floor_amount

    @floor_amount.setter
    def floor_amount(self, value):
        self._floor_amount = value
    @property
    def overdue_refundable(self):
        return self._overdue_refundable

    @overdue_refundable.setter
    def overdue_refundable(self, value):
        self._overdue_refundable = value
    @property
    def refundable(self):
        return self._refundable

    @refundable.setter
    def refundable(self, value):
        self._refundable = value
    @property
    def sale_amount(self):
        return self._sale_amount

    @sale_amount.setter
    def sale_amount(self, value):
        self._sale_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.floor_amount:
            if hasattr(self.floor_amount, 'to_alipay_dict'):
                params['floor_amount'] = self.floor_amount.to_alipay_dict()
            else:
                params['floor_amount'] = self.floor_amount
        if self.overdue_refundable:
            if hasattr(self.overdue_refundable, 'to_alipay_dict'):
                params['overdue_refundable'] = self.overdue_refundable.to_alipay_dict()
            else:
                params['overdue_refundable'] = self.overdue_refundable
        if self.refundable:
            if hasattr(self.refundable, 'to_alipay_dict'):
                params['refundable'] = self.refundable.to_alipay_dict()
            else:
                params['refundable'] = self.refundable
        if self.sale_amount:
            if hasattr(self.sale_amount, 'to_alipay_dict'):
                params['sale_amount'] = self.sale_amount.to_alipay_dict()
            else:
                params['sale_amount'] = self.sale_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityExchangeVoucher()
        if 'amount' in d:
            o.amount = d['amount']
        if 'floor_amount' in d:
            o.floor_amount = d['floor_amount']
        if 'overdue_refundable' in d:
            o.overdue_refundable = d['overdue_refundable']
        if 'refundable' in d:
            o.refundable = d['refundable']
        if 'sale_amount' in d:
            o.sale_amount = d['sale_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserBenefitInfo(object):

    def __init__(self):
        self._end_date = None
        self._id = None
        self._jump_url = None
        self._product_type = None
        self._start_date = None
        self._sub_title = None
        self._title = None
        self._voucher_quantity = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def jump_url(self):
        return self._jump_url

    @jump_url.setter
    def jump_url(self, value):
        self._jump_url = value
    @property
    def product_type(self):
        return self._product_type

    @product_type.setter
    def product_type(self, value):
        self._product_type = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def sub_title(self):
        return self._sub_title

    @sub_title.setter
    def sub_title(self, value):
        self._sub_title = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def voucher_quantity(self):
        return self._voucher_quantity

    @voucher_quantity.setter
    def voucher_quantity(self, value):
        self._voucher_quantity = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.jump_url:
            if hasattr(self.jump_url, 'to_alipay_dict'):
                params['jump_url'] = self.jump_url.to_alipay_dict()
            else:
                params['jump_url'] = self.jump_url
        if self.product_type:
            if hasattr(self.product_type, 'to_alipay_dict'):
                params['product_type'] = self.product_type.to_alipay_dict()
            else:
                params['product_type'] = self.product_type
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.sub_title:
            if hasattr(self.sub_title, 'to_alipay_dict'):
                params['sub_title'] = self.sub_title.to_alipay_dict()
            else:
                params['sub_title'] = self.sub_title
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.voucher_quantity:
            if hasattr(self.voucher_quantity, 'to_alipay_dict'):
                params['voucher_quantity'] = self.voucher_quantity.to_alipay_dict()
            else:
                params['voucher_quantity'] = self.voucher_quantity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserBenefitInfo()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'id' in d:
            o.id = d['id']
        if 'jump_url' in d:
            o.jump_url = d['jump_url']
        if 'product_type' in d:
            o.product_type = d['product_type']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'sub_title' in d:
            o.sub_title = d['sub_title']
        if 'title' in d:
            o.title = d['title']
        if 'voucher_quantity' in d:
            o.voucher_quantity = d['voucher_quantity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvoiceTradeGoodsItem(object):

    def __init__(self):
        self._category = None
        self._goods_name = None
        self._goods_no = None
        self._goods_sum_amount = None
        self._price = None
        self._quantity = None
        self._specification = None
        self._unit = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def goods_no(self):
        return self._goods_no

    @goods_no.setter
    def goods_no(self, value):
        self._goods_no = value
    @property
    def goods_sum_amount(self):
        return self._goods_sum_amount

    @goods_sum_amount.setter
    def goods_sum_amount(self, value):
        self._goods_sum_amount = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def specification(self):
        return self._specification

    @specification.setter
    def specification(self, value):
        self._specification = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.goods_no:
            if hasattr(self.goods_no, 'to_alipay_dict'):
                params['goods_no'] = self.goods_no.to_alipay_dict()
            else:
                params['goods_no'] = self.goods_no
        if self.goods_sum_amount:
            if hasattr(self.goods_sum_amount, 'to_alipay_dict'):
                params['goods_sum_amount'] = self.goods_sum_amount.to_alipay_dict()
            else:
                params['goods_sum_amount'] = self.goods_sum_amount
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.specification:
            if hasattr(self.specification, 'to_alipay_dict'):
                params['specification'] = self.specification.to_alipay_dict()
            else:
                params['specification'] = self.specification
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceTradeGoodsItem()
        if 'category' in d:
            o.category = d['category']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'goods_no' in d:
            o.goods_no = d['goods_no']
        if 'goods_sum_amount' in d:
            o.goods_sum_amount = d['goods_sum_amount']
        if 'price' in d:
            o.price = d['price']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'specification' in d:
            o.specification = d['specification']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingDataSmartactivityForecastModel(object):

    def __init__(self):
        self._config_code = None
        self._diagnose_code = None
        self._ext_info = None

    @property
    def config_code(self):
        return self._config_code

    @config_code.setter
    def config_code(self, value):
        self._config_code = value
    @property
    def diagnose_code(self):
        return self._diagnose_code

    @diagnose_code.setter
    def diagnose_code(self, value):
        self._diagnose_code = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.config_code:
            if hasattr(self.config_code, 'to_alipay_dict'):
                params['config_code'] = self.config_code.to_alipay_dict()
            else:
                params['config_code'] = self.config_code
        if self.diagnose_code:
            if hasattr(self.diagnose_code, 'to_alipay_dict'):
                params['diagnose_code'] = self.diagnose_code.to_alipay_dict()
            else:
                params['diagnose_code'] = self.diagnose_code
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingDataSmartactivityForecastModel()
        if 'config_code' in d:
            o.config_code = d['config_code']
        if 'diagnose_code' in d:
            o.diagnose_code = d['diagnose_code']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BizResult import BizResult


class AnttechBlockchainDefinBaseFileSubmitResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinBaseFileSubmitResponse, self).__init__()
        self._biz_result = None

    @property
    def biz_result(self):
        return self._biz_result

    @biz_result.setter
    def biz_result(self, value):
        if isinstance(value, BizResult):
            self._biz_result = value
        else:
            self._biz_result = BizResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinBaseFileSubmitResponse, self).parse_response_content(response_content)
        if 'biz_result' in response:
            self.biz_result = response['biz_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFinanceQuotationStocktoolsFreeuserExchangeModel(object):

    def __init__(self):
        self._inst_org_id = None
        self._tool_type = None
        self._user_id = None

    @property
    def inst_org_id(self):
        return self._inst_org_id

    @inst_org_id.setter
    def inst_org_id(self, value):
        self._inst_org_id = value
    @property
    def tool_type(self):
        return self._tool_type

    @tool_type.setter
    def tool_type(self, value):
        self._tool_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.inst_org_id:
            if hasattr(self.inst_org_id, 'to_alipay_dict'):
                params['inst_org_id'] = self.inst_org_id.to_alipay_dict()
            else:
                params['inst_org_id'] = self.inst_org_id
        if self.tool_type:
            if hasattr(self.tool_type, 'to_alipay_dict'):
                params['tool_type'] = self.tool_type.to_alipay_dict()
            else:
                params['tool_type'] = self.tool_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinanceQuotationStocktoolsFreeuserExchangeModel()
        if 'inst_org_id' in d:
            o.inst_org_id = d['inst_org_id']
        if 'tool_type' in d:
            o.tool_type = d['tool_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserCertifyIdentifyInfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserCertifyIdentifyInfoQueryResponse, self).__init__()
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._certify_grade = None
        self._certify_time = None
        self._havana_id = None
        self._is_certified = None
        self._is_released = None
        self._logon_id = None
        self._org_customer_expire_date = None
        self._org_customer_is_cancelled = None
        self._org_customer_is_exception = None
        self._org_customer_is_in_black_list = None
        self._org_customer_is_revoked = None
        self._org_customer_issue_date = None
        self._org_customer_legal_person_cert_name = None
        self._org_customer_legal_person_cert_no = None
        self._org_customer_legal_person_cert_type = None
        self._org_customer_legal_person_expire_date = None
        self._org_customer_legal_person_pictures = None
        self._org_customer_nature = None
        self._org_customer_open_date = None
        self._org_customer_pictures = None
        self._org_customer_registered_capital = None
        self._org_customer_scope = None
        self._person_customer_expire_date = None
        self._person_customer_pictures = None
        self._person_user_expire_date = None
        self._person_user_pictures = None
        self._user_id = None
        self._user_type = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def certify_grade(self):
        return self._certify_grade

    @certify_grade.setter
    def certify_grade(self, value):
        self._certify_grade = value
    @property
    def certify_time(self):
        return self._certify_time

    @certify_time.setter
    def certify_time(self, value):
        self._certify_time = value
    @property
    def havana_id(self):
        return self._havana_id

    @havana_id.setter
    def havana_id(self, value):
        self._havana_id = value
    @property
    def is_certified(self):
        return self._is_certified

    @is_certified.setter
    def is_certified(self, value):
        self._is_certified = value
    @property
    def is_released(self):
        return self._is_released

    @is_released.setter
    def is_released(self, value):
        self._is_released = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def org_customer_expire_date(self):
        return self._org_customer_expire_date

    @org_customer_expire_date.setter
    def org_customer_expire_date(self, value):
        self._org_customer_expire_date = value
    @property
    def org_customer_is_cancelled(self):
        return self._org_customer_is_cancelled

    @org_customer_is_cancelled.setter
    def org_customer_is_cancelled(self, value):
        self._org_customer_is_cancelled = value
    @property
    def org_customer_is_exception(self):
        return self._org_customer_is_exception

    @org_customer_is_exception.setter
    def org_customer_is_exception(self, value):
        self._org_customer_is_exception = value
    @property
    def org_customer_is_in_black_list(self):
        return self._org_customer_is_in_black_list

    @org_customer_is_in_black_list.setter
    def org_customer_is_in_black_list(self, value):
        self._org_customer_is_in_black_list = value
    @property
    def org_customer_is_revoked(self):
        return self._org_customer_is_revoked

    @org_customer_is_revoked.setter
    def org_customer_is_revoked(self, value):
        self._org_customer_is_revoked = value
    @property
    def org_customer_issue_date(self):
        return self._org_customer_issue_date

    @org_customer_issue_date.setter
    def org_customer_issue_date(self, value):
        self._org_customer_issue_date = value
    @property
    def org_customer_legal_person_cert_name(self):
        return self._org_customer_legal_person_cert_name

    @org_customer_legal_person_cert_name.setter
    def org_customer_legal_person_cert_name(self, value):
        self._org_customer_legal_person_cert_name = value
    @property
    def org_customer_legal_person_cert_no(self):
        return self._org_customer_legal_person_cert_no

    @org_customer_legal_person_cert_no.setter
    def org_customer_legal_person_cert_no(self, value):
        self._org_customer_legal_person_cert_no = value
    @property
    def org_customer_legal_person_cert_type(self):
        return self._org_customer_legal_person_cert_type

    @org_customer_legal_person_cert_type.setter
    def org_customer_legal_person_cert_type(self, value):
        self._org_customer_legal_person_cert_type = value
    @property
    def org_customer_legal_person_expire_date(self):
        return self._org_customer_legal_person_expire_date

    @org_customer_legal_person_expire_date.setter
    def org_customer_legal_person_expire_date(self, value):
        self._org_customer_legal_person_expire_date = value
    @property
    def org_customer_legal_person_pictures(self):
        return self._org_customer_legal_person_pictures

    @org_customer_legal_person_pictures.setter
    def org_customer_legal_person_pictures(self, value):
        if isinstance(value, list):
            self._org_customer_legal_person_pictures = list()
            for i in value:
                self._org_customer_legal_person_pictures.append(i)
    @property
    def org_customer_nature(self):
        return self._org_customer_nature

    @org_customer_nature.setter
    def org_customer_nature(self, value):
        self._org_customer_nature = value
    @property
    def org_customer_open_date(self):
        return self._org_customer_open_date

    @org_customer_open_date.setter
    def org_customer_open_date(self, value):
        self._org_customer_open_date = value
    @property
    def org_customer_pictures(self):
        return self._org_customer_pictures

    @org_customer_pictures.setter
    def org_customer_pictures(self, value):
        if isinstance(value, list):
            self._org_customer_pictures = list()
            for i in value:
                self._org_customer_pictures.append(i)
    @property
    def org_customer_registered_capital(self):
        return self._org_customer_registered_capital

    @org_customer_registered_capital.setter
    def org_customer_registered_capital(self, value):
        self._org_customer_registered_capital = value
    @property
    def org_customer_scope(self):
        return self._org_customer_scope

    @org_customer_scope.setter
    def org_customer_scope(self, value):
        self._org_customer_scope = value
    @property
    def person_customer_expire_date(self):
        return self._person_customer_expire_date

    @person_customer_expire_date.setter
    def person_customer_expire_date(self, value):
        self._person_customer_expire_date = value
    @property
    def person_customer_pictures(self):
        return self._person_customer_pictures

    @person_customer_pictures.setter
    def person_customer_pictures(self, value):
        if isinstance(value, list):
            self._person_customer_pictures = list()
            for i in value:
                self._person_customer_pictures.append(i)
    @property
    def person_user_expire_date(self):
        return self._person_user_expire_date

    @person_user_expire_date.setter
    def person_user_expire_date(self, value):
        self._person_user_expire_date = value
    @property
    def person_user_pictures(self):
        return self._person_user_pictures

    @person_user_pictures.setter
    def person_user_pictures(self, value):
        if isinstance(value, list):
            self._person_user_pictures = list()
            for i in value:
                self._person_user_pictures.append(i)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserCertifyIdentifyInfoQueryResponse, self).parse_response_content(response_content)
        if 'cert_name' in response:
            self.cert_name = response['cert_name']
        if 'cert_no' in response:
            self.cert_no = response['cert_no']
        if 'cert_type' in response:
            self.cert_type = response['cert_type']
        if 'certify_grade' in response:
            self.certify_grade = response['certify_grade']
        if 'certify_time' in response:
            self.certify_time = response['certify_time']
        if 'havana_id' in response:
            self.havana_id = response['havana_id']
        if 'is_certified' in response:
            self.is_certified = response['is_certified']
        if 'is_released' in response:
            self.is_released = response['is_released']
        if 'logon_id' in response:
            self.logon_id = response['logon_id']
        if 'org_customer_expire_date' in response:
            self.org_customer_expire_date = response['org_customer_expire_date']
        if 'org_customer_is_cancelled' in response:
            self.org_customer_is_cancelled = response['org_customer_is_cancelled']
        if 'org_customer_is_exception' in response:
            self.org_customer_is_exception = response['org_customer_is_exception']
        if 'org_customer_is_in_black_list' in response:
            self.org_customer_is_in_black_list = response['org_customer_is_in_black_list']
        if 'org_customer_is_revoked' in response:
            self.org_customer_is_revoked = response['org_customer_is_revoked']
        if 'org_customer_issue_date' in response:
            self.org_customer_issue_date = response['org_customer_issue_date']
        if 'org_customer_legal_person_cert_name' in response:
            self.org_customer_legal_person_cert_name = response['org_customer_legal_person_cert_name']
        if 'org_customer_legal_person_cert_no' in response:
            self.org_customer_legal_person_cert_no = response['org_customer_legal_person_cert_no']
        if 'org_customer_legal_person_cert_type' in response:
            self.org_customer_legal_person_cert_type = response['org_customer_legal_person_cert_type']
        if 'org_customer_legal_person_expire_date' in response:
            self.org_customer_legal_person_expire_date = response['org_customer_legal_person_expire_date']
        if 'org_customer_legal_person_pictures' in response:
            self.org_customer_legal_person_pictures = response['org_customer_legal_person_pictures']
        if 'org_customer_nature' in response:
            self.org_customer_nature = response['org_customer_nature']
        if 'org_customer_open_date' in response:
            self.org_customer_open_date = response['org_customer_open_date']
        if 'org_customer_pictures' in response:
            self.org_customer_pictures = response['org_customer_pictures']
        if 'org_customer_registered_capital' in response:
            self.org_customer_registered_capital = response['org_customer_registered_capital']
        if 'org_customer_scope' in response:
            self.org_customer_scope = response['org_customer_scope']
        if 'person_customer_expire_date' in response:
            self.person_customer_expire_date = response['person_customer_expire_date']
        if 'person_customer_pictures' in response:
            self.person_customer_pictures = response['person_customer_pictures']
        if 'person_user_expire_date' in response:
            self.person_user_expire_date = response['person_user_expire_date']
        if 'person_user_pictures' in response:
            self.person_user_pictures = response['person_user_pictures']
        if 'user_id' in response:
            self.user_id = response['user_id']
        if 'user_type' in response:
            self.user_type = response['user_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusRealtimeInfo(object):

    def __init__(self):
        self._line_id = None
        self._line_name = None
        self._seconds_left = None
        self._station_id = None
        self._station_left = None
        self._station_name = None
        self._sub_status = None
        self._sub_text = None

    @property
    def line_id(self):
        return self._line_id

    @line_id.setter
    def line_id(self, value):
        self._line_id = value
    @property
    def line_name(self):
        return self._line_name

    @line_name.setter
    def line_name(self, value):
        self._line_name = value
    @property
    def seconds_left(self):
        return self._seconds_left

    @seconds_left.setter
    def seconds_left(self, value):
        self._seconds_left = value
    @property
    def station_id(self):
        return self._station_id

    @station_id.setter
    def station_id(self, value):
        self._station_id = value
    @property
    def station_left(self):
        return self._station_left

    @station_left.setter
    def station_left(self, value):
        self._station_left = value
    @property
    def station_name(self):
        return self._station_name

    @station_name.setter
    def station_name(self, value):
        self._station_name = value
    @property
    def sub_status(self):
        return self._sub_status

    @sub_status.setter
    def sub_status(self, value):
        self._sub_status = value
    @property
    def sub_text(self):
        return self._sub_text

    @sub_text.setter
    def sub_text(self, value):
        self._sub_text = value


    def to_alipay_dict(self):
        params = dict()
        if self.line_id:
            if hasattr(self.line_id, 'to_alipay_dict'):
                params['line_id'] = self.line_id.to_alipay_dict()
            else:
                params['line_id'] = self.line_id
        if self.line_name:
            if hasattr(self.line_name, 'to_alipay_dict'):
                params['line_name'] = self.line_name.to_alipay_dict()
            else:
                params['line_name'] = self.line_name
        if self.seconds_left:
            if hasattr(self.seconds_left, 'to_alipay_dict'):
                params['seconds_left'] = self.seconds_left.to_alipay_dict()
            else:
                params['seconds_left'] = self.seconds_left
        if self.station_id:
            if hasattr(self.station_id, 'to_alipay_dict'):
                params['station_id'] = self.station_id.to_alipay_dict()
            else:
                params['station_id'] = self.station_id
        if self.station_left:
            if hasattr(self.station_left, 'to_alipay_dict'):
                params['station_left'] = self.station_left.to_alipay_dict()
            else:
                params['station_left'] = self.station_left
        if self.station_name:
            if hasattr(self.station_name, 'to_alipay_dict'):
                params['station_name'] = self.station_name.to_alipay_dict()
            else:
                params['station_name'] = self.station_name
        if self.sub_status:
            if hasattr(self.sub_status, 'to_alipay_dict'):
                params['sub_status'] = self.sub_status.to_alipay_dict()
            else:
                params['sub_status'] = self.sub_status
        if self.sub_text:
            if hasattr(self.sub_text, 'to_alipay_dict'):
                params['sub_text'] = self.sub_text.to_alipay_dict()
            else:
                params['sub_text'] = self.sub_text
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusRealtimeInfo()
        if 'line_id' in d:
            o.line_id = d['line_id']
        if 'line_name' in d:
            o.line_name = d['line_name']
        if 'seconds_left' in d:
            o.seconds_left = d['seconds_left']
        if 'station_id' in d:
            o.station_id = d['station_id']
        if 'station_left' in d:
            o.station_left = d['station_left']
        if 'station_name' in d:
            o.station_name = d['station_name']
        if 'sub_status' in d:
            o.sub_status = d['sub_status']
        if 'sub_text' in d:
            o.sub_text = d['sub_text']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MiniResourceRule import MiniResourceRule


class AlipayOpenMiniResourceCreateModel(object):

    def __init__(self):
        self._mode = None
        self._name = None
        self._row_num = None
        self._rule_list = None
        self._show_num = None
        self._type = None

    @property
    def mode(self):
        return self._mode

    @mode.setter
    def mode(self, value):
        self._mode = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def row_num(self):
        return self._row_num

    @row_num.setter
    def row_num(self, value):
        self._row_num = value
    @property
    def rule_list(self):
        return self._rule_list

    @rule_list.setter
    def rule_list(self, value):
        if isinstance(value, list):
            self._rule_list = list()
            for i in value:
                if isinstance(i, MiniResourceRule):
                    self._rule_list.append(i)
                else:
                    self._rule_list.append(MiniResourceRule.from_alipay_dict(i))
    @property
    def show_num(self):
        return self._show_num

    @show_num.setter
    def show_num(self, value):
        self._show_num = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.mode:
            if hasattr(self.mode, 'to_alipay_dict'):
                params['mode'] = self.mode.to_alipay_dict()
            else:
                params['mode'] = self.mode
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.row_num:
            if hasattr(self.row_num, 'to_alipay_dict'):
                params['row_num'] = self.row_num.to_alipay_dict()
            else:
                params['row_num'] = self.row_num
        if self.rule_list:
            if isinstance(self.rule_list, list):
                for i in range(0, len(self.rule_list)):
                    element = self.rule_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.rule_list[i] = element.to_alipay_dict()
            if hasattr(self.rule_list, 'to_alipay_dict'):
                params['rule_list'] = self.rule_list.to_alipay_dict()
            else:
                params['rule_list'] = self.rule_list
        if self.show_num:
            if hasattr(self.show_num, 'to_alipay_dict'):
                params['show_num'] = self.show_num.to_alipay_dict()
            else:
                params['show_num'] = self.show_num
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniResourceCreateModel()
        if 'mode' in d:
            o.mode = d['mode']
        if 'name' in d:
            o.name = d['name']
        if 'row_num' in d:
            o.row_num = d['row_num']
        if 'rule_list' in d:
            o.rule_list = d['rule_list']
        if 'show_num' in d:
            o.show_num = d['show_num']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsInfoIstd(object):

    def __init__(self):
        self._delivery_info = None
        self._first_class = None
        self._height = None
        self._length = None
        self._pickup_info = None
        self._price = None
        self._second_class = None
        self._weight = None
        self._width = None

    @property
    def delivery_info(self):
        return self._delivery_info

    @delivery_info.setter
    def delivery_info(self, value):
        self._delivery_info = value
    @property
    def first_class(self):
        return self._first_class

    @first_class.setter
    def first_class(self, value):
        self._first_class = value
    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, value):
        self._height = value
    @property
    def length(self):
        return self._length

    @length.setter
    def length(self, value):
        self._length = value
    @property
    def pickup_info(self):
        return self._pickup_info

    @pickup_info.setter
    def pickup_info(self, value):
        self._pickup_info = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def second_class(self):
        return self._second_class

    @second_class.setter
    def second_class(self, value):
        self._second_class = value
    @property
    def weight(self):
        return self._weight

    @weight.setter
    def weight(self, value):
        self._weight = value
    @property
    def width(self):
        return self._width

    @width.setter
    def width(self, value):
        self._width = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_info:
            if hasattr(self.delivery_info, 'to_alipay_dict'):
                params['delivery_info'] = self.delivery_info.to_alipay_dict()
            else:
                params['delivery_info'] = self.delivery_info
        if self.first_class:
            if hasattr(self.first_class, 'to_alipay_dict'):
                params['first_class'] = self.first_class.to_alipay_dict()
            else:
                params['first_class'] = self.first_class
        if self.height:
            if hasattr(self.height, 'to_alipay_dict'):
                params['height'] = self.height.to_alipay_dict()
            else:
                params['height'] = self.height
        if self.length:
            if hasattr(self.length, 'to_alipay_dict'):
                params['length'] = self.length.to_alipay_dict()
            else:
                params['length'] = self.length
        if self.pickup_info:
            if hasattr(self.pickup_info, 'to_alipay_dict'):
                params['pickup_info'] = self.pickup_info.to_alipay_dict()
            else:
                params['pickup_info'] = self.pickup_info
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.second_class:
            if hasattr(self.second_class, 'to_alipay_dict'):
                params['second_class'] = self.second_class.to_alipay_dict()
            else:
                params['second_class'] = self.second_class
        if self.weight:
            if hasattr(self.weight, 'to_alipay_dict'):
                params['weight'] = self.weight.to_alipay_dict()
            else:
                params['weight'] = self.weight
        if self.width:
            if hasattr(self.width, 'to_alipay_dict'):
                params['width'] = self.width.to_alipay_dict()
            else:
                params['width'] = self.width
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsInfoIstd()
        if 'delivery_info' in d:
            o.delivery_info = d['delivery_info']
        if 'first_class' in d:
            o.first_class = d['first_class']
        if 'height' in d:
            o.height = d['height']
        if 'length' in d:
            o.length = d['length']
        if 'pickup_info' in d:
            o.pickup_info = d['pickup_info']
        if 'price' in d:
            o.price = d['price']
        if 'second_class' in d:
            o.second_class = d['second_class']
        if 'weight' in d:
            o.weight = d['weight']
        if 'width' in d:
            o.width = d['width']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ConnectServerAdaptResult(object):

    def __init__(self):
        self._count = None
        self._is_service_time = None
        self._portal_msg = None
        self._visitor_id = None
        self._visitor_token = None
        self._visitor_type = None
        self._welcome = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def is_service_time(self):
        return self._is_service_time

    @is_service_time.setter
    def is_service_time(self, value):
        self._is_service_time = value
    @property
    def portal_msg(self):
        return self._portal_msg

    @portal_msg.setter
    def portal_msg(self, value):
        self._portal_msg = value
    @property
    def visitor_id(self):
        return self._visitor_id

    @visitor_id.setter
    def visitor_id(self, value):
        self._visitor_id = value
    @property
    def visitor_token(self):
        return self._visitor_token

    @visitor_token.setter
    def visitor_token(self, value):
        self._visitor_token = value
    @property
    def visitor_type(self):
        return self._visitor_type

    @visitor_type.setter
    def visitor_type(self, value):
        self._visitor_type = value
    @property
    def welcome(self):
        return self._welcome

    @welcome.setter
    def welcome(self, value):
        self._welcome = value


    def to_alipay_dict(self):
        params = dict()
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.is_service_time:
            if hasattr(self.is_service_time, 'to_alipay_dict'):
                params['is_service_time'] = self.is_service_time.to_alipay_dict()
            else:
                params['is_service_time'] = self.is_service_time
        if self.portal_msg:
            if hasattr(self.portal_msg, 'to_alipay_dict'):
                params['portal_msg'] = self.portal_msg.to_alipay_dict()
            else:
                params['portal_msg'] = self.portal_msg
        if self.visitor_id:
            if hasattr(self.visitor_id, 'to_alipay_dict'):
                params['visitor_id'] = self.visitor_id.to_alipay_dict()
            else:
                params['visitor_id'] = self.visitor_id
        if self.visitor_token:
            if hasattr(self.visitor_token, 'to_alipay_dict'):
                params['visitor_token'] = self.visitor_token.to_alipay_dict()
            else:
                params['visitor_token'] = self.visitor_token
        if self.visitor_type:
            if hasattr(self.visitor_type, 'to_alipay_dict'):
                params['visitor_type'] = self.visitor_type.to_alipay_dict()
            else:
                params['visitor_type'] = self.visitor_type
        if self.welcome:
            if hasattr(self.welcome, 'to_alipay_dict'):
                params['welcome'] = self.welcome.to_alipay_dict()
            else:
                params['welcome'] = self.welcome
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ConnectServerAdaptResult()
        if 'count' in d:
            o.count = d['count']
        if 'is_service_time' in d:
            o.is_service_time = d['is_service_time']
        if 'portal_msg' in d:
            o.portal_msg = d['portal_msg']
        if 'visitor_id' in d:
            o.visitor_id = d['visitor_id']
        if 'visitor_token' in d:
            o.visitor_token = d['visitor_token']
        if 'visitor_type' in d:
            o.visitor_type = d['visitor_type']
        if 'welcome' in d:
            o.welcome = d['welcome']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MaintainVehicleInfo import MaintainVehicleInfo


class AlipayEcoMycarDataserviceMaintainvehicleShareResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarDataserviceMaintainvehicleShareResponse, self).__init__()
        self._info = None

    @property
    def info(self):
        return self._info

    @info.setter
    def info(self, value):
        if isinstance(value, MaintainVehicleInfo):
            self._info = value
        else:
            self._info = MaintainVehicleInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarDataserviceMaintainvehicleShareResponse, self).parse_response_content(response_content)
        if 'info' in response:
            self.info = response['info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoCityserviceAppinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCityserviceAppinfoQueryResponse, self).__init__()
        self._biz_type = None
        self._result_code = None
        self._result_context = None
        self._result_msg = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_context(self):
        return self._result_context

    @result_context.setter
    def result_context(self, value):
        self._result_context = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCityserviceAppinfoQueryResponse, self).parse_response_content(response_content)
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_context' in response:
            self.result_context = response['result_context']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CertAuditResult import CertAuditResult


class ZolozIdentificationCustomerIdcardCertifyResponse(AlipayResponse):

    def __init__(self):
        super(ZolozIdentificationCustomerIdcardCertifyResponse, self).__init__()
        self._cert_audit_result = None
        self._passed = None
        self._token = None

    @property
    def cert_audit_result(self):
        return self._cert_audit_result

    @cert_audit_result.setter
    def cert_audit_result(self, value):
        if isinstance(value, list):
            self._cert_audit_result = list()
            for i in value:
                if isinstance(i, CertAuditResult):
                    self._cert_audit_result.append(i)
                else:
                    self._cert_audit_result.append(CertAuditResult.from_alipay_dict(i))
    @property
    def passed(self):
        return self._passed

    @passed.setter
    def passed(self, value):
        self._passed = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value

    def parse_response_content(self, response_content):
        response = super(ZolozIdentificationCustomerIdcardCertifyResponse, self).parse_response_content(response_content)
        if 'cert_audit_result' in response:
            self.cert_audit_result = response['cert_audit_result']
        if 'passed' in response:
            self.passed = response['passed']
        if 'token' in response:
            self.token = response['token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOfflineMarketMcommentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOfflineMarketMcommentQueryResponse, self).__init__()
        self._comment_id = None
        self._comment_status = None
        self._comment_time = None
        self._score = None

    @property
    def comment_id(self):
        return self._comment_id

    @comment_id.setter
    def comment_id(self, value):
        self._comment_id = value
    @property
    def comment_status(self):
        return self._comment_status

    @comment_status.setter
    def comment_status(self, value):
        self._comment_status = value
    @property
    def comment_time(self):
        return self._comment_time

    @comment_time.setter
    def comment_time(self, value):
        self._comment_time = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value

    def parse_response_content(self, response_content):
        response = super(AlipayOfflineMarketMcommentQueryResponse, self).parse_response_content(response_content)
        if 'comment_id' in response:
            self.comment_id = response['comment_id']
        if 'comment_status' in response:
            self.comment_status = response['comment_status']
        if 'comment_time' in response:
            self.comment_time = response['comment_time']
        if 'score' in response:
            self.score = response['score']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMsaasMediarecogMmtcaftscvTemplateVerifyModel(object):

    def __init__(self):
        self._algorithm_goods_ids = None
        self._good_count = None
        self._machine_type_id = None
        self._scene_id = None
        self._template_id = None

    @property
    def algorithm_goods_ids(self):
        return self._algorithm_goods_ids

    @algorithm_goods_ids.setter
    def algorithm_goods_ids(self, value):
        if isinstance(value, list):
            self._algorithm_goods_ids = list()
            for i in value:
                self._algorithm_goods_ids.append(i)
    @property
    def good_count(self):
        return self._good_count

    @good_count.setter
    def good_count(self, value):
        self._good_count = value
    @property
    def machine_type_id(self):
        return self._machine_type_id

    @machine_type_id.setter
    def machine_type_id(self, value):
        self._machine_type_id = value
    @property
    def scene_id(self):
        return self._scene_id

    @scene_id.setter
    def scene_id(self, value):
        self._scene_id = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.algorithm_goods_ids:
            if isinstance(self.algorithm_goods_ids, list):
                for i in range(0, len(self.algorithm_goods_ids)):
                    element = self.algorithm_goods_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.algorithm_goods_ids[i] = element.to_alipay_dict()
            if hasattr(self.algorithm_goods_ids, 'to_alipay_dict'):
                params['algorithm_goods_ids'] = self.algorithm_goods_ids.to_alipay_dict()
            else:
                params['algorithm_goods_ids'] = self.algorithm_goods_ids
        if self.good_count:
            if hasattr(self.good_count, 'to_alipay_dict'):
                params['good_count'] = self.good_count.to_alipay_dict()
            else:
                params['good_count'] = self.good_count
        if self.machine_type_id:
            if hasattr(self.machine_type_id, 'to_alipay_dict'):
                params['machine_type_id'] = self.machine_type_id.to_alipay_dict()
            else:
                params['machine_type_id'] = self.machine_type_id
        if self.scene_id:
            if hasattr(self.scene_id, 'to_alipay_dict'):
                params['scene_id'] = self.scene_id.to_alipay_dict()
            else:
                params['scene_id'] = self.scene_id
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMsaasMediarecogMmtcaftscvTemplateVerifyModel()
        if 'algorithm_goods_ids' in d:
            o.algorithm_goods_ids = d['algorithm_goods_ids']
        if 'good_count' in d:
            o.good_count = d['good_count']
        if 'machine_type_id' in d:
            o.machine_type_id = d['machine_type_id']
        if 'scene_id' in d:
            o.scene_id = d['scene_id']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.QrCodeOperationLog import QrCodeOperationLog


class AlipayCommerceGreenItemUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceGreenItemUploadResponse, self).__init__()
        self._failed_qr_code_log_list = None

    @property
    def failed_qr_code_log_list(self):
        return self._failed_qr_code_log_list

    @failed_qr_code_log_list.setter
    def failed_qr_code_log_list(self, value):
        if isinstance(value, list):
            self._failed_qr_code_log_list = list()
            for i in value:
                if isinstance(i, QrCodeOperationLog):
                    self._failed_qr_code_log_list.append(i)
                else:
                    self._failed_qr_code_log_list.append(QrCodeOperationLog.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceGreenItemUploadResponse, self).parse_response_content(response_content)
        if 'failed_qr_code_log_list' in response:
            self.failed_qr_code_log_list = response['failed_qr_code_log_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class AlipayEbppBillAddRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._bank_bill_no = None
        self._bill_date = None
        self._bill_key = None
        self._charge_inst = None
        self._extend_field = None
        self._merchant_order_no = None
        self._mobile = None
        self._order_type = None
        self._owner_name = None
        self._pay_amount = None
        self._service_amount = None
        self._sub_order_type = None
        self._traffic_location = None
        self._traffic_regulations = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def bank_bill_no(self):
        return self._bank_bill_no

    @bank_bill_no.setter
    def bank_bill_no(self, value):
        self._bank_bill_no = value
    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def owner_name(self):
        return self._owner_name

    @owner_name.setter
    def owner_name(self, value):
        self._owner_name = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def service_amount(self):
        return self._service_amount

    @service_amount.setter
    def service_amount(self, value):
        self._service_amount = value
    @property
    def sub_order_type(self):
        return self._sub_order_type

    @sub_order_type.setter
    def sub_order_type(self, value):
        self._sub_order_type = value
    @property
    def traffic_location(self):
        return self._traffic_location

    @traffic_location.setter
    def traffic_location(self, value):
        self._traffic_location = value
    @property
    def traffic_regulations(self):
        return self._traffic_regulations

    @traffic_regulations.setter
    def traffic_regulations(self, value):
        self._traffic_regulations = value


    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'alipay.ebpp.bill.add'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.bank_bill_no:
            if hasattr(self.bank_bill_no, 'to_alipay_dict'):
                params['bank_bill_no'] = json.dumps(obj=self.bank_bill_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['bank_bill_no'] = self.bank_bill_no
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = json.dumps(obj=self.bill_date.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['bill_date'] = self.bill_date
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = json.dumps(obj=self.bill_key.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['bill_key'] = self.bill_key
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = json.dumps(obj=self.charge_inst.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['charge_inst'] = self.charge_inst
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = json.dumps(obj=self.extend_field.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['extend_field'] = self.extend_field
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = json.dumps(obj=self.merchant_order_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = json.dumps(obj=self.mobile.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['mobile'] = self.mobile
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = json.dumps(obj=self.order_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['order_type'] = self.order_type
        if self.owner_name:
            if hasattr(self.owner_name, 'to_alipay_dict'):
                params['owner_name'] = json.dumps(obj=self.owner_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['owner_name'] = self.owner_name
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = json.dumps(obj=self.pay_amount.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['pay_amount'] = self.pay_amount
        if self.service_amount:
            if hasattr(self.service_amount, 'to_alipay_dict'):
                params['service_amount'] = json.dumps(obj=self.service_amount.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['service_amount'] = self.service_amount
        if self.sub_order_type:
            if hasattr(self.sub_order_type, 'to_alipay_dict'):
                params['sub_order_type'] = json.dumps(obj=self.sub_order_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['sub_order_type'] = self.sub_order_type
        if self.traffic_location:
            if hasattr(self.traffic_location, 'to_alipay_dict'):
                params['traffic_location'] = json.dumps(obj=self.traffic_location.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['traffic_location'] = self.traffic_location
        if self.traffic_regulations:
            if hasattr(self.traffic_regulations, 'to_alipay_dict'):
                params['traffic_regulations'] = json.dumps(obj=self.traffic_regulations.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['traffic_regulations'] = self.traffic_regulations
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignCertCreateModel(object):

    def __init__(self):
        self._cert_name = None
        self._extend_info = None
        self._memo = None
        self._valid_count = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def valid_count(self):
        return self._valid_count

    @valid_count.setter
    def valid_count(self, value):
        self._valid_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.valid_count:
            if hasattr(self.valid_count, 'to_alipay_dict'):
                params['valid_count'] = self.valid_count.to_alipay_dict()
            else:
                params['valid_count'] = self.valid_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignCertCreateModel()
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'memo' in d:
            o.memo = d['memo']
        if 'valid_count' in d:
            o.valid_count = d['valid_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniResourceRule(object):

    def __init__(self):
        self._floor_id = None
        self._identity_id = None
        self._identity_name = None
        self._item_id_list = None
        self._origin = None
        self._rule_id = None
        self._rule_name = None
        self._type = None

    @property
    def floor_id(self):
        return self._floor_id

    @floor_id.setter
    def floor_id(self, value):
        self._floor_id = value
    @property
    def identity_id(self):
        return self._identity_id

    @identity_id.setter
    def identity_id(self, value):
        self._identity_id = value
    @property
    def identity_name(self):
        return self._identity_name

    @identity_name.setter
    def identity_name(self, value):
        self._identity_name = value
    @property
    def item_id_list(self):
        return self._item_id_list

    @item_id_list.setter
    def item_id_list(self, value):
        self._item_id_list = value
    @property
    def origin(self):
        return self._origin

    @origin.setter
    def origin(self, value):
        self._origin = value
    @property
    def rule_id(self):
        return self._rule_id

    @rule_id.setter
    def rule_id(self, value):
        self._rule_id = value
    @property
    def rule_name(self):
        return self._rule_name

    @rule_name.setter
    def rule_name(self, value):
        self._rule_name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.floor_id:
            if hasattr(self.floor_id, 'to_alipay_dict'):
                params['floor_id'] = self.floor_id.to_alipay_dict()
            else:
                params['floor_id'] = self.floor_id
        if self.identity_id:
            if hasattr(self.identity_id, 'to_alipay_dict'):
                params['identity_id'] = self.identity_id.to_alipay_dict()
            else:
                params['identity_id'] = self.identity_id
        if self.identity_name:
            if hasattr(self.identity_name, 'to_alipay_dict'):
                params['identity_name'] = self.identity_name.to_alipay_dict()
            else:
                params['identity_name'] = self.identity_name
        if self.item_id_list:
            if hasattr(self.item_id_list, 'to_alipay_dict'):
                params['item_id_list'] = self.item_id_list.to_alipay_dict()
            else:
                params['item_id_list'] = self.item_id_list
        if self.origin:
            if hasattr(self.origin, 'to_alipay_dict'):
                params['origin'] = self.origin.to_alipay_dict()
            else:
                params['origin'] = self.origin
        if self.rule_id:
            if hasattr(self.rule_id, 'to_alipay_dict'):
                params['rule_id'] = self.rule_id.to_alipay_dict()
            else:
                params['rule_id'] = self.rule_id
        if self.rule_name:
            if hasattr(self.rule_name, 'to_alipay_dict'):
                params['rule_name'] = self.rule_name.to_alipay_dict()
            else:
                params['rule_name'] = self.rule_name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniResourceRule()
        if 'floor_id' in d:
            o.floor_id = d['floor_id']
        if 'identity_id' in d:
            o.identity_id = d['identity_id']
        if 'identity_name' in d:
            o.identity_name = d['identity_name']
        if 'item_id_list' in d:
            o.item_id_list = d['item_id_list']
        if 'origin' in d:
            o.origin = d['origin']
        if 'rule_id' in d:
            o.rule_id = d['rule_id']
        if 'rule_name' in d:
            o.rule_name = d['rule_name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MpPrizeInfoModel import MpPrizeInfoModel


class AlipayMarketingCampaignDrawcampQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignDrawcampQueryResponse, self).__init__()
        self._account_count = None
        self._appid_count = None
        self._award_count = None
        self._award_rate = None
        self._camp_code = None
        self._camp_end_time = None
        self._camp_id = None
        self._camp_name = None
        self._camp_start_time = None
        self._camp_status = None
        self._cert_rule_id = None
        self._certification_count = None
        self._creator = None
        self._crowd_rule_id = None
        self._mobile_count = None
        self._prize_list = None
        self._promo_rule_id = None
        self._trigger_type = None
        self._trigger_user_rule_id = None
        self._user_rule_id = None

    @property
    def account_count(self):
        return self._account_count

    @account_count.setter
    def account_count(self, value):
        self._account_count = value
    @property
    def appid_count(self):
        return self._appid_count

    @appid_count.setter
    def appid_count(self, value):
        self._appid_count = value
    @property
    def award_count(self):
        return self._award_count

    @award_count.setter
    def award_count(self, value):
        self._award_count = value
    @property
    def award_rate(self):
        return self._award_rate

    @award_rate.setter
    def award_rate(self, value):
        self._award_rate = value
    @property
    def camp_code(self):
        return self._camp_code

    @camp_code.setter
    def camp_code(self, value):
        self._camp_code = value
    @property
    def camp_end_time(self):
        return self._camp_end_time

    @camp_end_time.setter
    def camp_end_time(self, value):
        self._camp_end_time = value
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def camp_name(self):
        return self._camp_name

    @camp_name.setter
    def camp_name(self, value):
        self._camp_name = value
    @property
    def camp_start_time(self):
        return self._camp_start_time

    @camp_start_time.setter
    def camp_start_time(self, value):
        self._camp_start_time = value
    @property
    def camp_status(self):
        return self._camp_status

    @camp_status.setter
    def camp_status(self, value):
        self._camp_status = value
    @property
    def cert_rule_id(self):
        return self._cert_rule_id

    @cert_rule_id.setter
    def cert_rule_id(self, value):
        self._cert_rule_id = value
    @property
    def certification_count(self):
        return self._certification_count

    @certification_count.setter
    def certification_count(self, value):
        self._certification_count = value
    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def crowd_rule_id(self):
        return self._crowd_rule_id

    @crowd_rule_id.setter
    def crowd_rule_id(self, value):
        self._crowd_rule_id = value
    @property
    def mobile_count(self):
        return self._mobile_count

    @mobile_count.setter
    def mobile_count(self, value):
        self._mobile_count = value
    @property
    def prize_list(self):
        return self._prize_list

    @prize_list.setter
    def prize_list(self, value):
        if isinstance(value, list):
            self._prize_list = list()
            for i in value:
                if isinstance(i, MpPrizeInfoModel):
                    self._prize_list.append(i)
                else:
                    self._prize_list.append(MpPrizeInfoModel.from_alipay_dict(i))
    @property
    def promo_rule_id(self):
        return self._promo_rule_id

    @promo_rule_id.setter
    def promo_rule_id(self, value):
        self._promo_rule_id = value
    @property
    def trigger_type(self):
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, value):
        self._trigger_type = value
    @property
    def trigger_user_rule_id(self):
        return self._trigger_user_rule_id

    @trigger_user_rule_id.setter
    def trigger_user_rule_id(self, value):
        self._trigger_user_rule_id = value
    @property
    def user_rule_id(self):
        return self._user_rule_id

    @user_rule_id.setter
    def user_rule_id(self, value):
        self._user_rule_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignDrawcampQueryResponse, self).parse_response_content(response_content)
        if 'account_count' in response:
            self.account_count = response['account_count']
        if 'appid_count' in response:
            self.appid_count = response['appid_count']
        if 'award_count' in response:
            self.award_count = response['award_count']
        if 'award_rate' in response:
            self.award_rate = response['award_rate']
        if 'camp_code' in response:
            self.camp_code = response['camp_code']
        if 'camp_end_time' in response:
            self.camp_end_time = response['camp_end_time']
        if 'camp_id' in response:
            self.camp_id = response['camp_id']
        if 'camp_name' in response:
            self.camp_name = response['camp_name']
        if 'camp_start_time' in response:
            self.camp_start_time = response['camp_start_time']
        if 'camp_status' in response:
            self.camp_status = response['camp_status']
        if 'cert_rule_id' in response:
            self.cert_rule_id = response['cert_rule_id']
        if 'certification_count' in response:
            self.certification_count = response['certification_count']
        if 'creator' in response:
            self.creator = response['creator']
        if 'crowd_rule_id' in response:
            self.crowd_rule_id = response['crowd_rule_id']
        if 'mobile_count' in response:
            self.mobile_count = response['mobile_count']
        if 'prize_list' in response:
            self.prize_list = response['prize_list']
        if 'promo_rule_id' in response:
            self.promo_rule_id = response['promo_rule_id']
        if 'trigger_type' in response:
            self.trigger_type = response['trigger_type']
        if 'trigger_user_rule_id' in response:
            self.trigger_user_rule_id = response['trigger_user_rule_id']
        if 'user_rule_id' in response:
            self.user_rule_id = response['user_rule_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsDataAutodamageEstimateResultDetailModel(object):

    def __init__(self):
        self._damage_degree = None
        self._damage_degree_desc = None
        self._damage_type = None
        self._damage_type_desc = None
        self._hourly_wage = None
        self._old_recycle = None
        self._origin_images = None
        self._parts_cost = None
        self._parts_id = None
        self._parts_manage_fee = None
        self._parts_name = None
        self._remain_value = None
        self._repair_type = None
        self._repair_type_desc = None

    @property
    def damage_degree(self):
        return self._damage_degree

    @damage_degree.setter
    def damage_degree(self, value):
        self._damage_degree = value
    @property
    def damage_degree_desc(self):
        return self._damage_degree_desc

    @damage_degree_desc.setter
    def damage_degree_desc(self, value):
        self._damage_degree_desc = value
    @property
    def damage_type(self):
        return self._damage_type

    @damage_type.setter
    def damage_type(self, value):
        self._damage_type = value
    @property
    def damage_type_desc(self):
        return self._damage_type_desc

    @damage_type_desc.setter
    def damage_type_desc(self, value):
        self._damage_type_desc = value
    @property
    def hourly_wage(self):
        return self._hourly_wage

    @hourly_wage.setter
    def hourly_wage(self, value):
        self._hourly_wage = value
    @property
    def old_recycle(self):
        return self._old_recycle

    @old_recycle.setter
    def old_recycle(self, value):
        self._old_recycle = value
    @property
    def origin_images(self):
        return self._origin_images

    @origin_images.setter
    def origin_images(self, value):
        self._origin_images = value
    @property
    def parts_cost(self):
        return self._parts_cost

    @parts_cost.setter
    def parts_cost(self, value):
        self._parts_cost = value
    @property
    def parts_id(self):
        return self._parts_id

    @parts_id.setter
    def parts_id(self, value):
        self._parts_id = value
    @property
    def parts_manage_fee(self):
        return self._parts_manage_fee

    @parts_manage_fee.setter
    def parts_manage_fee(self, value):
        self._parts_manage_fee = value
    @property
    def parts_name(self):
        return self._parts_name

    @parts_name.setter
    def parts_name(self, value):
        self._parts_name = value
    @property
    def remain_value(self):
        return self._remain_value

    @remain_value.setter
    def remain_value(self, value):
        self._remain_value = value
    @property
    def repair_type(self):
        return self._repair_type

    @repair_type.setter
    def repair_type(self, value):
        self._repair_type = value
    @property
    def repair_type_desc(self):
        return self._repair_type_desc

    @repair_type_desc.setter
    def repair_type_desc(self, value):
        self._repair_type_desc = value


    def to_alipay_dict(self):
        params = dict()
        if self.damage_degree:
            if hasattr(self.damage_degree, 'to_alipay_dict'):
                params['damage_degree'] = self.damage_degree.to_alipay_dict()
            else:
                params['damage_degree'] = self.damage_degree
        if self.damage_degree_desc:
            if hasattr(self.damage_degree_desc, 'to_alipay_dict'):
                params['damage_degree_desc'] = self.damage_degree_desc.to_alipay_dict()
            else:
                params['damage_degree_desc'] = self.damage_degree_desc
        if self.damage_type:
            if hasattr(self.damage_type, 'to_alipay_dict'):
                params['damage_type'] = self.damage_type.to_alipay_dict()
            else:
                params['damage_type'] = self.damage_type
        if self.damage_type_desc:
            if hasattr(self.damage_type_desc, 'to_alipay_dict'):
                params['damage_type_desc'] = self.damage_type_desc.to_alipay_dict()
            else:
                params['damage_type_desc'] = self.damage_type_desc
        if self.hourly_wage:
            if hasattr(self.hourly_wage, 'to_alipay_dict'):
                params['hourly_wage'] = self.hourly_wage.to_alipay_dict()
            else:
                params['hourly_wage'] = self.hourly_wage
        if self.old_recycle:
            if hasattr(self.old_recycle, 'to_alipay_dict'):
                params['old_recycle'] = self.old_recycle.to_alipay_dict()
            else:
                params['old_recycle'] = self.old_recycle
        if self.origin_images:
            if hasattr(self.origin_images, 'to_alipay_dict'):
                params['origin_images'] = self.origin_images.to_alipay_dict()
            else:
                params['origin_images'] = self.origin_images
        if self.parts_cost:
            if hasattr(self.parts_cost, 'to_alipay_dict'):
                params['parts_cost'] = self.parts_cost.to_alipay_dict()
            else:
                params['parts_cost'] = self.parts_cost
        if self.parts_id:
            if hasattr(self.parts_id, 'to_alipay_dict'):
                params['parts_id'] = self.parts_id.to_alipay_dict()
            else:
                params['parts_id'] = self.parts_id
        if self.parts_manage_fee:
            if hasattr(self.parts_manage_fee, 'to_alipay_dict'):
                params['parts_manage_fee'] = self.parts_manage_fee.to_alipay_dict()
            else:
                params['parts_manage_fee'] = self.parts_manage_fee
        if self.parts_name:
            if hasattr(self.parts_name, 'to_alipay_dict'):
                params['parts_name'] = self.parts_name.to_alipay_dict()
            else:
                params['parts_name'] = self.parts_name
        if self.remain_value:
            if hasattr(self.remain_value, 'to_alipay_dict'):
                params['remain_value'] = self.remain_value.to_alipay_dict()
            else:
                params['remain_value'] = self.remain_value
        if self.repair_type:
            if hasattr(self.repair_type, 'to_alipay_dict'):
                params['repair_type'] = self.repair_type.to_alipay_dict()
            else:
                params['repair_type'] = self.repair_type
        if self.repair_type_desc:
            if hasattr(self.repair_type_desc, 'to_alipay_dict'):
                params['repair_type_desc'] = self.repair_type_desc.to_alipay_dict()
            else:
                params['repair_type_desc'] = self.repair_type_desc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsDataAutodamageEstimateResultDetailModel()
        if 'damage_degree' in d:
            o.damage_degree = d['damage_degree']
        if 'damage_degree_desc' in d:
            o.damage_degree_desc = d['damage_degree_desc']
        if 'damage_type' in d:
            o.damage_type = d['damage_type']
        if 'damage_type_desc' in d:
            o.damage_type_desc = d['damage_type_desc']
        if 'hourly_wage' in d:
            o.hourly_wage = d['hourly_wage']
        if 'old_recycle' in d:
            o.old_recycle = d['old_recycle']
        if 'origin_images' in d:
            o.origin_images = d['origin_images']
        if 'parts_cost' in d:
            o.parts_cost = d['parts_cost']
        if 'parts_id' in d:
            o.parts_id = d['parts_id']
        if 'parts_manage_fee' in d:
            o.parts_manage_fee = d['parts_manage_fee']
        if 'parts_name' in d:
            o.parts_name = d['parts_name']
        if 'remain_value' in d:
            o.remain_value = d['remain_value']
        if 'repair_type' in d:
            o.repair_type = d['repair_type']
        if 'repair_type_desc' in d:
            o.repair_type_desc = d['repair_type_desc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BelongGreenMerchantInfo import BelongGreenMerchantInfo


class AlipayCommerceGreenItemenergySendModel(object):

    def __init__(self):
        self._alipay_uid = None
        self._belong_merchant_info = None
        self._goods_id = None
        self._goods_name = None
        self._industry_type = None
        self._order_link = None
        self._qr_code_id = None
        self._scan_time = None

    @property
    def alipay_uid(self):
        return self._alipay_uid

    @alipay_uid.setter
    def alipay_uid(self, value):
        self._alipay_uid = value
    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, BelongGreenMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = BelongGreenMerchantInfo.from_alipay_dict(value)
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def industry_type(self):
        return self._industry_type

    @industry_type.setter
    def industry_type(self, value):
        self._industry_type = value
    @property
    def order_link(self):
        return self._order_link

    @order_link.setter
    def order_link(self, value):
        self._order_link = value
    @property
    def qr_code_id(self):
        return self._qr_code_id

    @qr_code_id.setter
    def qr_code_id(self, value):
        self._qr_code_id = value
    @property
    def scan_time(self):
        return self._scan_time

    @scan_time.setter
    def scan_time(self, value):
        self._scan_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_uid:
            if hasattr(self.alipay_uid, 'to_alipay_dict'):
                params['alipay_uid'] = self.alipay_uid.to_alipay_dict()
            else:
                params['alipay_uid'] = self.alipay_uid
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.industry_type:
            if hasattr(self.industry_type, 'to_alipay_dict'):
                params['industry_type'] = self.industry_type.to_alipay_dict()
            else:
                params['industry_type'] = self.industry_type
        if self.order_link:
            if hasattr(self.order_link, 'to_alipay_dict'):
                params['order_link'] = self.order_link.to_alipay_dict()
            else:
                params['order_link'] = self.order_link
        if self.qr_code_id:
            if hasattr(self.qr_code_id, 'to_alipay_dict'):
                params['qr_code_id'] = self.qr_code_id.to_alipay_dict()
            else:
                params['qr_code_id'] = self.qr_code_id
        if self.scan_time:
            if hasattr(self.scan_time, 'to_alipay_dict'):
                params['scan_time'] = self.scan_time.to_alipay_dict()
            else:
                params['scan_time'] = self.scan_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceGreenItemenergySendModel()
        if 'alipay_uid' in d:
            o.alipay_uid = d['alipay_uid']
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'industry_type' in d:
            o.industry_type = d['industry_type']
        if 'order_link' in d:
            o.order_link = d['order_link']
        if 'qr_code_id' in d:
            o.qr_code_id = d['qr_code_id']
        if 'scan_time' in d:
            o.scan_time = d['scan_time']
        return o


